# 参考库

## RealmsPlayerlistBot
[如何使用prisma](https://github.com/AstreaTSS/RealmsPlayerlistBot)

## RuoYi-Vue-FastAPI
[如何使用fastapi](https://gitee.com/insistence2022/RuoYi-Vue-FastAPI)

## prisma-fastapi
这个包含了一个最基础的带jwt的框架
[prisma-fastapi](https://github.com/prisma-korea/prisma-fastapi)

## elytra-ms
[如何打包](https://github.com/Astrea-Stellarium-Labs/elytra-ms)

https://blog.csdn.net/Trb601012/article/details/135770544
pip install --upgrade build
pip install hatchling
python -m build
http://xpgh.stoneartifact.cn:4173/guide/15.PyPI%E4%B8%8A%E4%BC%A0wheel.html
twine upload -r pypi dist/*